==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Zkosené okraje</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Stíny</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Pozadí:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Stín:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Zvýraznění:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Chybějící obrázek.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prosím čekejte</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Nahrávání obrázku…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Vytváření skládanky…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Vytváření dílů…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Nahrávání skládanky…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Neznámý formát dat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Neznámý prvek „%1“</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Chyba při parsování XML souboru

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Nahrávání dílů…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Shromažďování dílů…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Rozmisťování dílů…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Vybrat hru</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Rozehrané hry</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nová hra</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Vlastnosti obrázku</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>jméno:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Štítky:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vyberte jazyk aplikace:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>Systémový jazyk</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Pro uplatnění změn v nastavení jazyka prosím ukončete a znovu spusťte aplikaci.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Přidat obrázek</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Odstranit obrázek</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Vlastnosti obrázku</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 dílů</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopírování obrázků…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Odstranit vybraný obrázek?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Odstranit vybraný obrázek?

Některé z rozehraných her používají tento obrázek, odstraníte-li jej, budou taktéž odstraněny.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nepojmenovaný</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Nepojmenovaný</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 dílů %2 %3% dokončeno</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Smazat hru</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Smazat vybranou hru?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Náhled</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Přidat štítek</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Odstranit štítek</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Bez štítku</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Všechny obrázky</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Nepojmenovaný %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Odstranit vybrané štítky?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Je nám líto</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Štítek s tímto jménem již existuje.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Shromáždit díly</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Vybrat…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobrazit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Přiblížit</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddálit</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>O&amp;ptimální zobrazení</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Zobrazit náhled</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Vzhled…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Jazyk…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Ovládání</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;O Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládání</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sebrání dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Levé tlačítko nebo mezerník</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Položení dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Výběr dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Tažení levým tlačítkem</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pootočení dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Pravé tlačítko, Ctrl + Levé tlačítko, nebo R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Přetažení skládanky:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Prostřední tlačítko, Shift + Levé tlačítko, nebo šipky</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Úroveň přiblížení skládanky:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Kolečko myši nebo +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pohyb kurzoru:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Myš nebo W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>O Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Skládanka s díly ve tvaru tetromina</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Zkosené okraje</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Stíny</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Pozadí:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Stín:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Zvýraznění:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Chybějící obrázek.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prosím čekejte</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Nahrávání obrázku…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Vytváření skládanky…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Vytváření dílů…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Nahrávání skládanky…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Neznámý formát dat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Neznámý prvek „%1“</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Chyba při parsování XML souboru

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Nahrávání dílů…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Shromažďování dílů…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Rozmisťování dílů…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Vybrat hru</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Rozehrané hry</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nová hra</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Vlastnosti obrázku</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>jméno:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Štítky:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vyberte jazyk aplikace:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>Systémový jazyk</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Pro uplatnění změn v nastavení jazyka prosím ukončete a znovu spusťte aplikaci.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Přidat obrázek</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Odstranit obrázek</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Vlastnosti obrázku</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 dílů</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopírování obrázků…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nepojmenovaný</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Nepojmenovaný</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 dílů %2 %3% dokončeno</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Smazat hru</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Smazat vybranou hru?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Náhled</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Přidat štítek</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Odstranit štítek</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Bez štítku</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Všechny obrázky</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Nepojmenovaný %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Odstranit vybrané štítky?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Je nám líto</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Štítek s tímto jménem již existuje.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Shromáždit díly</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Vybrat…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobrazit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Přiblížit</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddálit</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>O&amp;ptimální zobrazení</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Zobrazit náhled</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Vzhled…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Jazyk…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Ovládání</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;O Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládání</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sebrání dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Levé tlačítko nebo mezerník</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Položení dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Výběr dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Tažení levým tlačítkem</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pootočení dílů:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Pravé tlačítko, Ctrl + Levé tlačítko, nebo R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Přetažení skládanky:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Prostřední tlačítko, Shift + Levé tlačítko, nebo šipky</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Úroveň přiblížení skládanky:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Kolečko myši nebo +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pohyb kurzoru:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Myš nebo W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>O Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Skládanka s díly ve tvaru tetromina</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
